use strict;

package ASCOPE::Class::Text::Collection;

$ASCOPE::Class::Text::Collection::VERSION = '1.0';

use overload q("") => sub { join(' ',@{$_[0]}); };

sub new { my $pkg = shift; return bless [ @_ ], $pkg; }
sub add { my $self = shift; push @{$self},@_; }

return 1;

__END__

=head1 NAME

ASCOPE::Class::Text::Collection - Aaron's class thingy for holding a bunch
of ASCOPE::Class::Text::* thingies.

=head1 SYNOPSIS

 use ASCOPE::Class::Text;
 use ASCOPE::Class::Text::CDATA;
 use ASCOPE::Class::Text::Collection;

 my $collection = ASCOPE::Class::Text::Collection->new();

 $collection->add(ASCOPE::Class::Text->new("ook"));
 $collection->add(ASCOPE::Class::Text::CDATA->new("ook"));
 $collection->add(ASCOPE::Class::Text->new("ook"));

 print $collection;

 # prints:
 # ook <![CDATA[ook]]> ook

=head1 DESCRIPTION

Aaron's class thingy for holding a bunch of ASCOPE::Class::Text::* thingies.

Override the object's I<""> operator to join all of the elements passed to the
object and return a string.

=head1 PACKAGE METHODS

=head2 __PACKAGE__->new(@stuff)

Returns an object. Woot!

=head1 OBJECT METHODS

=head2 $obj->add(@stuff)

Add one or more elements to the object.

=head1 VERSION

1.0

=head1 DATE

$Date: 2003/03/12 02:33:31 $

=head1 SEE ALSO

L<ASCOPE::Class::Text>

=head1 LICENSE

Copyright (c) 2003, Aaron Straup Cope. All Rights Reserved.

This is free software, you may use it and distribute it under
the same terms as Perl itself.

=cut

